"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HydrationStream = exports.transformRow = void 0;
const stream_1 = __importDefault(require("stream"));
const ramda_1 = __importDefault(require("ramda"));
// instanceof doesn't work with instance of probably due to deps resolving?
function isBig(value) {
    if (typeof value === 'object' && value !== null) {
        return value.constructor.name === 'Big';
    }
    return false;
}
function transformRow(row) {
    return ramda_1.default.map((value) => {
        if (value && value.value && typeof value.value === 'string') {
            return value.value;
        }
        if (Buffer.isBuffer(value)) {
            return value.toString('base64');
        }
        if (isBig(value)) {
            return value.toString();
        }
        return value;
    }, row);
}
exports.transformRow = transformRow;
class HydrationStream extends stream_1.default.Transform {
    constructor() {
        super({
            objectMode: true,
            transform(row, encoding, callback) {
                const transformed = transformRow(row);
                this.push(transformed);
                callback();
            }
        });
    }
}
exports.HydrationStream = HydrationStream;
//# sourceMappingURL=HydrationStream.js.map